@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Dist::Zilla::PluginBundle::MITHALDU;
-our $VERSION = '1.150590'; # VERSION
+our $VERSION = '1.151340'; # VERSION
 
 # Dependencies
 use autodie 2.00;
@@ -208,7 +208,7 @@ sub configure {
   # gather and prune
     [ GatherDir => {
       exclude_filename => [@generated_files],
-      exclude_match => $self->exclude_match}
+      ( (scalar @{$self->exclude_match}) ? ('exclude_match' => $self->exclude_match) : () )}
     ], # core
     ['PruneCruft', { except => $self->prune_except }], # core
     'ManifestSkip',       # core
@@ -335,7 +335,7 @@ Dist::Zilla::PluginBundle::MITHALDU - Dist::Zilla configuration the way MITHALDU
 
 =head1 VERSION
 
-version 1.150590
+version 1.151340
 
 =head1 SYNOPSIS
 
